summaryrefslogtreecommitdiffstats
path: root/sync/test/engine/syncer_command_test.h
diff options
context:
space:
mode:
Diffstat (limited to 'sync/test/engine/syncer_command_test.h')
-rw-r--r--sync/test/engine/syncer_command_test.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/sync/test/engine/syncer_command_test.h b/sync/test/engine/syncer_command_test.h
index 803ef18..8e1aa14 100644
--- a/sync/test/engine/syncer_command_test.h
+++ b/sync/test/engine/syncer_command_test.h
@@ -98,10 +98,10 @@ class SyncerCommandTestBase : public testing::Test,
sessions::SyncSessionContext* context() const { return context_.get(); }
sessions::SyncSession::Delegate* delegate() { return this; }
// Lazily create a session requesting all datatypes with no payload.
sessions::SyncSession* session() {
- ModelTypePayloadMap types =
- ModelSafeRoutingInfoToPayloadMap(routing_info_, std::string());
+ ModelTypeStateMap types =
+ ModelSafeRoutingInfoToStateMap(routing_info_, std::string());
return session(sessions::SyncSourceInfo(types));
}
@@ -98,10 +98,10 @@ class SyncerCommandTestBase : public testing::Test,
sessions::SyncSessionContext* context() const { return context_.get(); }
sessions::SyncSession::Delegate* delegate() { return this; }
- // Lazily create a session requesting all datatypes with no payload.
+ // Lazily create a session requesting all datatypes with no state.
sessions::SyncSession* session() {